@@ -24,6 +24,8 @@
 # include <io.h>
 #endif
 
+#define static_assert(x, ...) switch ((int) (x)) case 0: case !!((int) (x)):
+
 
 Gt_Frame def_frame;
 
@@ -1253,6 +1255,13 @@ copy_crop(Gt_Crop *oc)
 int
 main(int argc, char *argv[])
 {
+  /* Check SIZEOF constants (useful for Windows). If these assertions fail,
+     you've used the wrong Makefile. You should've used Makefile.w32 for
+     32-bit Windows and Makefile.w64 for 64-bit Windows. */
+  static_assert(sizeof(unsigned int) == SIZEOF_UNSIGNED_INT, "unsigned int has the wrong size.");
+  static_assert(sizeof(unsigned long) == SIZEOF_UNSIGNED_LONG, "unsigned long has the wrong size.");
+  static_assert(sizeof(void*) == SIZEOF_VOID_P, "void* has the wrong size.");
+
   Clp_Parser *clp =
     Clp_NewParser(argc, (const char * const *)argv, sizeof(options) / sizeof(options[0]), options);
 
