@@ -217,10 +217,14 @@ combine_crop(Gt_Crop *dstcrop, const Gt_Crop *srccrop, const Gif_Image *gfi)
 	dstcrop->w += dstcrop->x, dstcrop->x = 0;
     if (dstcrop->y < 0)
 	dstcrop->h += dstcrop->y, dstcrop->y = 0;
-    if (dstcrop->x + dstcrop->w > gfi->width)
+    if (dstcrop->w > 0 && dstcrop->x + dstcrop->w > gfi->width)
 	dstcrop->w = gfi->width - dstcrop->x;
-    if (dstcrop->y + dstcrop->h > gfi->height)
+    if (dstcrop->h > 0 && dstcrop->y + dstcrop->h > gfi->height)
 	dstcrop->h = gfi->height - dstcrop->y;
+    if (dstcrop->w < 0)
+        dstcrop->w = 0;
+    if (dstcrop->h < 0)
+        dstcrop->h = 0;
 }
 
 int
@@ -439,7 +443,9 @@ resize_stream(Gif_Stream *gfs, int new_width, int new_height, int fit)
   double xfactor, yfactor;
   int i;
 
+  fprintf(stderr, "%d %d %d %d\n", gfs->screen_width, gfs->screen_height, 0,0);
   Gif_CalculateScreenSize(gfs, 0);
+  fprintf(stderr, "%d %d %d %d\n", gfs->screen_width, gfs->screen_height, 0,0);
   xfactor = (double) new_width / gfs->screen_width;
   yfactor = (double) new_height / gfs->screen_height;
 
@@ -470,4 +476,5 @@ resize_stream(Gif_Stream *gfs, int new_width, int new_height, int fit)
 
   gfs->screen_width = new_width;
   gfs->screen_height = new_height;
+  fprintf(stderr, "%d %d %d %d\n", gfs->screen_width, gfs->screen_height, 0,0);
 }
